if { [lsearch $auto_path [file dirname [info script]]] == -1 } {
	lappend auto_path [file dirname [info script]]
}
package ifneeded tcllib 0.8 {
	package require base64
	package require cmdline
	package require counter
	package require struct
	package require fileutil
	package require ftp
	package require ftpd
	package require javascript
	package require html
	package require math
	package require mime
	package require ncgi
	package require nntp
	package require pop3
	package require profiler
	package require textutil
	package require uri
	package provide tcllib 0.8
}
